#ifndef BOOL_DEFINED
# define BOOL_DEFINED 1
#if defined __STDC__ && defined __STDC_VERSION__ && __STDC_VERSION__ >= 199901L
	/* have a C99 compiler */
	typedef _Bool boolean;
#else
	/* do not have a C99 compiler */
	typedef unsigned char boolean;
	#define true 1
	#define false 0
#endif
#endif

// <stx> character
#define STX                         ((char)0x02)
// Command byte values...
#define INTERROGATE                 ((char)0x01)
#define CLEAR_BAR_CODES             ((char)0x02)
#define DOWNLOAD_PARAMETERS         ((char)0x03)
#define RESERVED_CODE_4             ((char)0x04)
#define POWER_DOWN                  ((char)0x05)
#define RESERVED_CODE_6             ((char)0x06)
#define UPLOAD                      ((char)0x07)
#define UPLOAD_PARAMETERS           ((char)0x08)
#define SEND_SIGNATURE              ((char)0x0C)

// CSP device status value...
#define NO_ERROR_ENCOUNTERED        ((char)6)
#define STATUS_OK                   0
#define COMMUNICATIONS_ERROR       -1
#define LRC_FAILED                 -2
#define NOBC_INIT                  -3
#define READ_TIMEOUT               -4

// 5 read- or send-retries
#define MAXTIME                     ((int)  5)
// maximum size of retrieved barcodes
#define MAXSIZE                     ((int)4096)
// communications RX buffer setting
#define RX_QUE_SIZE                 ((int)1024)
// communications Tx buffer setting
#define TX_QUE_SIZE                 ((int) 512)

/*--------------------------------------------
 * Functions for communication with CyberPen
 *--------------------------------------------
 */
void cspErrMsg( char errcode );

char cspWakeup( void );
char cspGetCodes( void );
char cspClear( void );
char cspPOff( void );


/*----------------------------------------------
 * Functions for communication with other libs
 *----------------------------------------------
 */
int cspNBarcodes( void );
char cspProtoType( void );
char cspSysstat( void );
char *cspUserId( void );
char *cspSwVersion( void );
char *cspBarData( void );


/*-------------------------------------------
 * Functions for setting up the serial port
 *-------------------------------------------
 */
int open_port( char *port );
int init_port( void );
int close_port( void );
